@@ -128,9 +128,16 @@ class FacileToolkit2:
         """
         This keyword cleans the current session in order to isolate the execution
         """
+        self._wait_until(
+            self._clear_session,
+            "Could not clear session in <TIMEOUT>."
+        )
+
+    def _clear_session(self):
         self.set_selenium_library()
         self.sl.delete_all_cookies()
         self.sl.reload_page()
+        return True
 
     @keyword
     def scroll(self, range="0"):
@@ -379,6 +386,10 @@ class FacileToolkit2:
             timeout = self.ajax_activation
         self.sl.wait_for_condition('if(typeof(jQuery) == "function") {return jQuery.active == 1} return false', timeout)
 
+    @keyword
+    def wait_ajax_optional(self, timeout=None, wait_active=None):
+        BuiltIn().run_keyword_and_ignore_error("wait_ajax", timeout, wait_active)
+        
     @keyword
     def field_or_parents_should_contain_error(self, locator, timeout=None, error_class="wrong", error=None):
         self.wait_ultil_element_or_parents_contain_class(locator, error_class, timeout, error)
